Index: lemon/maps.h
===================================================================
--- lemon/maps.h	(revision 559)
+++ lemon/maps.h	(revision 572)
@@ -1833,5 +1833,5 @@
   /// \c GR::Edge).
   ///
-  /// \see DescriptorMap
+  /// \see RangeIdMap
   template <typename GR, typename K>
   class IdMap : public MapBase<K, int> {
@@ -1899,5 +1899,5 @@
 
 
   /// \brief General invertable graph map type.
 
   /// This class provides simple invertable graph maps.
@@ -1916,5 +1916,5 @@
   /// \see IterableValueMap
   template <typename GR, typename K, typename V>
-  class InvertableMap
+  class CrossRefMap
     : protected ItemSetTraits<GR, K>::template Map<V>::Type {
   private:
@@ -1928,17 +1928,17 @@
   public:
 
     /// The graph type of InvertableMap.
     typedef GR Graph;
     /// The key type of InvertableMap (\c Node, \c Arc or \c Edge).
     typedef K Item;
     /// The key type of InvertableMap (\c Node, \c Arc or \c Edge).
     typedef K Key;
     /// The value type of InvertableMap.
     typedef V Value;
 
     /// \brief Constructor.
     ///
-    /// Construct a new InvertableMap for the given graph.
-    explicit InvertableMap(const Graph& graph) : Map(graph) {}
+    /// Construct a new CrossRefMap for the given graph.
+    explicit CrossRefMap(const Graph& graph) : Map(graph) {}
 
     /// \brief Forward iterator for values.
@@ -1949,5 +1949,5 @@
     class ValueIterator
       : public std::iterator<std::forward_iterator_tag, Value> {
-      friend class InvertableMap;
+      friend class CrossRefMap;
     private:
       ValueIterator(typename Container::const_iterator _it)
@@ -2073,11 +2073,11 @@
       ///
       /// Constructor of the InverseMap.
-      explicit InverseMap(const InvertableMap& inverted)
+      explicit InverseMap(const CrossRefMap& inverted)
         : _inverted(inverted) {}
 
       /// The value type of the InverseMap.
-      typedef typename InvertableMap::Key Value;
+      typedef typename CrossRefMap::Key Value;
       /// The key type of the InverseMap.
-      typedef typename InvertableMap::Value Key;
+      typedef typename CrossRefMap::Value Key;
 
       /// \brief Subscript operator.
@@ -2090,5 +2090,5 @@
 
     private:
-      const InvertableMap& _inverted;
+      const CrossRefMap& _inverted;
     };
 
@@ -2102,16 +2102,15 @@
   };
 
   /// \brief Provides a mutable, continuous and unique descriptor for each
   /// item in a graph.
   ///
   /// DescriptorMap provides a unique and continuous (but mutable)
   /// descriptor (id) for each item of the same type (\c Node, \c Arc or
   /// \c Edge) in a graph. This id is
   ///  - \b unique: different items get different ids,
   ///  - \b continuous: the range of the ids is the set of integers
   ///    between 0 and \c n-1, where \c n is the number of the items of
-  ///    this type (\c Node, \c Arc or \c Edge). So the id of an item can
-  ///    change if you delete an other item of the same type, i.e. this
-  ///    id is mutable.
+  ///    this type (\c Node, \c Arc or \c Edge).
+  ///  - So, the ids can change when deleting an item of the same type.
   ///
   /// Thus this id is not (necessarily) the same as what can get using
@@ -2126,5 +2125,5 @@
   /// \see IdMap
   template <typename GR, typename K>
-  class DescriptorMap
+  class RangeIdMap
     : protected ItemSetTraits<GR, K>::template Map<int>::Type {
 
@@ -2132,17 +2131,17 @@
 
   public:
     /// The graph type of DescriptorMap.
     typedef GR Graph;
     /// The key type of DescriptorMap (\c Node, \c Arc or \c Edge).
     typedef K Item;
     /// The key type of DescriptorMap (\c Node, \c Arc or \c Edge).
     typedef K Key;
     /// The value type of DescriptorMap.
     typedef int Value;
 
     /// \brief Constructor.
     ///
-    /// Constructor for descriptor map.
-    explicit DescriptorMap(const Graph& gr) : Map(gr) {
+    /// Constructor.
+    explicit RangeIdMap(const Graph& gr) : Map(gr) {
       Item it;
       const typename Map::Notifier* nf = Map::notifier();
@@ -2245,14 +2244,14 @@
     }
 
     /// \brief Gives back the \e descriptor of the item.
     ///
     /// Gives back the mutable and unique \e descriptor of the map.
     int operator[](const Item& item) const {
       return Map::operator[](item);
     }
 
     /// \brief Gives back the item by its descriptor.
     ///
     /// Gives back th item by its descriptor.
     Item operator()(int id) const {
       return _inv_map[id];
@@ -2266,7 +2265,7 @@
   public:
 
     /// \brief The inverse map type of DescriptorMap.
     ///
     /// The inverse map type of DescriptorMap.
     class InverseMap {
     public:
@@ -2274,12 +2273,12 @@
       ///
       /// Constructor of the InverseMap.
-      explicit InverseMap(const DescriptorMap& inverted)
+      explicit InverseMap(const RangeIdMap& inverted)
         : _inverted(inverted) {}
 
 
       /// The value type of the InverseMap.
-      typedef typename DescriptorMap::Key Value;
+      typedef typename RangeIdMap::Key Value;
       /// The key type of the InverseMap.
-      typedef typename DescriptorMap::Value Key;
+      typedef typename RangeIdMap::Value Key;
 
       /// \brief Subscript operator.
@@ -2299,5 +2298,5 @@
 
     private:
-      const DescriptorMap& _inverted;
+      const RangeIdMap& _inverted;
     };
 
@@ -1899,5 +1899,5 @@
 
 
-  /// \brief General invertable graph map type.
+  /// \brief General cross reference graph map type.
 
   /// This class provides simple invertable graph maps.
@@ -1928,17 +1928,17 @@
   public:
 
-    /// The graph type of InvertableMap.
+    /// The graph type of CrossRefMap.
     typedef GR Graph;
@@ -1928,17 +1928,17 @@
     typedef GR Graph;
-    /// The key type of InvertableMap (\c Node, \c Arc or \c Edge).
+    /// The key type of CrossRefMap (\c Node, \c Arc or \c Edge).
     typedef K Item;
@@ -1928,17 +1928,17 @@
     typedef K Item;
-    /// The key type of InvertableMap (\c Node, \c Arc or \c Edge).
+    /// The key type of CrossRefMap (\c Node, \c Arc or \c Edge).
     typedef K Key;
@@ -1928,17 +1928,17 @@
     typedef K Key;
-    /// The value type of InvertableMap.
+    /// The value type of CrossRefMap.
     typedef V Value;
 
@@ -2102,16 +2102,15 @@
   };
 
-  /// \brief Provides a mutable, continuous and unique descriptor for each
-  /// item in a graph.
-  ///
-  /// DescriptorMap provides a unique and continuous (but mutable)
-  /// descriptor (id) for each item of the same type (\c Node, \c Arc or
+  /// \brief Provides continuous and unique ID for the
+  /// items of a graph.
+  ///
+  /// RangeIdMap provides a unique and continuous
+  /// ID for each item of a given type (\c Node, \c Arc or
   /// \c Edge) in a graph. This id is
   ///  - \b unique: different items get different ids,
@@ -2132,17 +2131,17 @@
 
   public:
-    /// The graph type of DescriptorMap.
+    /// The graph type of RangeIdMap.
     typedef GR Graph;
@@ -2132,17 +2131,17 @@
     typedef GR Graph;
-    /// The key type of DescriptorMap (\c Node, \c Arc or \c Edge).
+    /// The key type of RangeIdMap (\c Node, \c Arc or \c Edge).
     typedef K Item;
@@ -2132,17 +2131,17 @@
     typedef K Item;
-    /// The key type of DescriptorMap (\c Node, \c Arc or \c Edge).
+    /// The key type of RangeIdMap (\c Node, \c Arc or \c Edge).
     typedef K Key;
@@ -2132,17 +2131,17 @@
     typedef K Key;
-    /// The value type of DescriptorMap.
+    /// The value type of RangeIdMap.
     typedef int Value;
 
@@ -2245,14 +2244,14 @@
     }
 
-    /// \brief Gives back the \e descriptor of the item.
-    ///
-    /// Gives back the mutable and unique \e descriptor of the map.
+    /// \brief Gives back the \e RangeId of the item
+    ///
+    /// Gives back the \e RangeId of the item.
     int operator[](const Item& item) const {
       return Map::operator[](item);
@@ -2245,14 +2244,14 @@
     }
 
-    /// \brief Gives back the item by its descriptor.
-    ///
-    /// Gives back th item by its descriptor.
+    /// \brief Gives back the item belonging to a \e RangeId
+    /// 
+    /// Gives back the item belonging to a \e RangeId.
     Item operator()(int id) const {
       return _inv_map[id];
@@ -2266,7 +2265,7 @@
   public:
 
-    /// \brief The inverse map type of DescriptorMap.
-    ///
-    /// The inverse map type of DescriptorMap.
+    /// \brief The inverse map type of RangeIdMap.
+    ///
+    /// The inverse map type of RangeIdMap.
     class InverseMap {
     public:
